OSSP CVS Repository

ossp - Difference in ossp-pkg/as/as-gui/as_dataop.cpp versions 1.31 and 1.32
Not logged in
[Honeypot]  [Browse]  [Home]  [Login]  [Reports
[Search]  [Ticket]  [Timeline
  [History

ossp-pkg/as/as-gui/as_dataop.cpp 1.31 -> 1.32

--- as_dataop.cpp        2002/12/20 15:13:52     1.31
+++ as_dataop.cpp        2002/12/20 17:42:10     1.32
@@ -262,8 +262,11 @@
         }
     }
 
-    // Start sorting order correctly according to user preferences
-    m_pMaintable->sortColumn((int)m_pPrefs->getNumber(TITRAQ_PREFSORT, TITRAQ_DEFSORT));
+    // Start sorting order and direction correctly according to user preferences
+    int nSortcol = (int)m_pPrefs->getNumber(TITRAQ_PREFSORTCOL, TITRAQ_DEFSORTCOL);
+    bool bSortdir = m_pPrefs->getBool(TITRAQ_PREFSORTDIR, TITRAQ_DEFSORTDIR);
+    m_pMaintable->setSortdir(!bSortdir); // Hack! Fake sortdir so we start right
+    m_pMaintable->sortColumn(nSortcol, bSortdir);
 
     // Write nonsaving line numbers for all rows
     for (int nIter = m_pMaintable->numRows() - 1; nIter >= 0; nIter--)

CVSTrac 2.0.1